@@ -6,7 +6,7 @@ use Module::Build::Platform::Unix;
 use vars qw(@ISA);
 @ISA = qw(Module::Build::Platform::Unix);
 
-sub need_prelink_c { 1 }
+sub manpage_separator { '.' }
 
 1;
 __END__
